@@ -1,6 +1,6 @@
 ;;; llm-ollama.el --- llm module for integrating with Ollama. -*- lexical-binding: t; package-lint-main-file: "llm.el"; -*-
 
-;; Copyright (c) 2023, 2024  Free Software Foundation, Inc.
+;; Copyright (c) 2023-2025  Free Software Foundation, Inc.
 
 ;; Author: Andrew Hyatt <ahyatt@gmail.com>
 ;; Homepage: https://github.com/ahyatt/llm
@@ -91,8 +91,8 @@ EMBEDDING-MODEL is the model to use for embeddings.  It is required."
 (cl-defmethod llm-provider-embedding-request ((provider llm-ollama) string)
   "Return the request to the server for the embedding of STRING.
 PROVIDER is the llm-ollama provider."
-  `(("input" . ,string)
-    ("model" . ,(llm-ollama-embedding-model provider))))
+  `(:input ,string
+           :model ,(llm-ollama-embedding-model provider)))
 
 (cl-defmethod llm-provider-batch-embeddings-request ((provider llm-ollama) strings)
   (llm-provider-embedding-request provider strings))
@@ -112,73 +112,73 @@ PROVIDER is the llm-ollama provider."
   "Return the response format for FORMAT."
   (if (eq format 'json)
       :json
-    (llm-provider-utils-json-schema format)))
+    (llm-provider-utils-convert-to-serializable format)))
 
 (cl-defmethod llm-provider-chat-request ((provider llm-ollama) prompt streaming)
-  (let (request-alist messages options)
+  (llm-provider-utils-combine-to-system-prompt prompt llm-ollama-example-prelude)
+  (let (request-plist messages options)
     (setq messages
-          (mapcar (lambda (interaction)
-                    (let* ((role (llm-chat-prompt-interaction-role interaction))
-                           (content (llm-chat-prompt-interaction-content interaction))
-                           (content-text "")
-                           (images nil))
-                      (if (stringp content)
-                          (setq content-text content)
-                        (if (eq 'user role)
-                            (dolist (part (llm-multipart-parts content))
-                              (if (llm-media-p part)
-                                  (setq images (append images (list part)))
-                                (setq content-text (concat content-text part))))
-                          (setq content-text (json-encode content))))
-                      (append
-                       `(("role" . ,(symbol-name role)))
-                       `(("content" . ,content-text))
-                       (when images
-                         `(("images" .
-                            ,(mapcar (lambda (img) (base64-encode-string (llm-media-data img) t))
-                                     images)))))))
-                  (llm-chat-prompt-interactions prompt)))
-    (when (llm-chat-prompt-context prompt)
-      (push `(("role" . "system")
-              ("content" . ,(llm-provider-utils-get-system-prompt prompt llm-ollama-example-prelude)))
-            messages))
-    (push `("messages" . ,messages) request-alist)
-    (push `("model" . ,(llm-ollama-chat-model provider)) request-alist)
-    (when (and streaming (llm-chat-prompt-functions prompt))
+          (vconcat (mapcar (lambda (interaction)
+                             (let* ((role (llm-chat-prompt-interaction-role interaction))
+                                    (content (llm-chat-prompt-interaction-content interaction))
+                                    (content-text "")
+                                    (images nil))
+                               (if (stringp content)
+                                   (setq content-text content)
+                                 (if (eq 'user role)
+                                     (dolist (part (llm-multipart-parts content))
+                                       (if (llm-media-p part)
+                                           (setq images (append images (list part)))
+                                         (setq content-text (concat content-text part))))
+                                   (setq content-text (json-serialize content))))
+                               (append
+                                `(:role ,(symbol-name role)
+                                        :content ,content-text)
+                                (when images
+                                  `(:images
+                                    ,(vconcat (mapcar (lambda (img) (base64-encode-string (llm-media-data img) t))
+                                                      images)))))))
+                           (llm-chat-prompt-interactions prompt))))
+    (setq request-plist (plist-put request-plist :messages messages))
+    (setq request-plist (plist-put request-plist :model (llm-ollama-chat-model provider)))
+    (when (and streaming (llm-chat-prompt-tools prompt))
       (signal 'not-implemented
               "Ollama does not support streaming with function calls"))
-    (when (llm-chat-prompt-functions prompt)
-      (push `("tools" . ,(mapcar #'llm-provider-utils-openai-function-spec
-                                 (llm-chat-prompt-functions prompt))) request-alist))
+    (when (llm-chat-prompt-tools prompt)
+      (setq request-plist (plist-put
+                           request-plist :tools
+                           (vconcat (mapcar #'llm-provider-utils-openai-tool-spec
+                                            (llm-chat-prompt-tools prompt))))))
     (when (llm-chat-prompt-response-format prompt)
-      (push `("format" . ,(llm-ollama--response-format
-                           (llm-chat-prompt-response-format prompt)))
-            request-alist))
-    (push `("stream" . ,(if streaming t :json-false)) request-alist)
+      (setq request-plist (plist-put request-plist :format
+                                     (llm-ollama--response-format
+                                      (llm-chat-prompt-response-format prompt)))))
+    (setq request-plist (plist-put request-plist :stream (if streaming t :false)))
     (when (llm-chat-prompt-temperature prompt)
-      (push `("temperature" . ,(llm-chat-prompt-temperature prompt)) options))
+      (setq options (plist-put options :temperature (llm-chat-prompt-temperature prompt))))
     (when (llm-chat-prompt-max-tokens prompt)
-      (push `("num_predict" . ,(llm-chat-prompt-max-tokens prompt)) options))
-    (setq options (append options (llm-chat-prompt-non-standard-params prompt)))
-    (when options (push `("options" . ,options) request-alist))
-    request-alist))
+      (setq options (plist-put options :num_predict (llm-chat-prompt-max-tokens prompt))))
+    (setq options (append options (llm-provider-utils-non-standard-params-plist prompt)))
+    (when options
+      (setq request-plist (plist-put request-plist :options options)))
+    request-plist))
 
-(cl-defmethod llm-provider-extract-function-calls ((_ llm-ollama) response)
+(cl-defmethod llm-provider-extract-tool-uses ((_ llm-ollama) response)
   (mapcar (lambda (call)
             (let ((function (cdar call)))
-              (make-llm-provider-utils-function-call
+              (make-llm-provider-utils-tool-use
                :name (assoc-default 'name function)
                :args (assoc-default 'arguments function))))
           (assoc-default 'tool_calls (assoc-default 'message response))))
 
-(cl-defmethod llm-provider-populate-function-calls ((_ llm-ollama) prompt calls)
+(cl-defmethod llm-provider-populate-tool-uses ((_ llm-ollama) prompt tool-uses)
   (llm-provider-utils-append-to-prompt
    prompt
-   (mapcar (lambda (call)
-             `((function (name . ,(llm-provider-utils-function-call-name call))
-                         (arguments . ,(json-encode
-                                        (llm-provider-utils-function-call-args call))))))
-           calls)))
+   (vconcat (mapcar (lambda (tool-use)
+                      `(:function (:name ,(llm-provider-utils-tool-use-name tool-use)
+                                         :arguments ,(json-serialize
+                                                      (llm-provider-utils-tool-use-args tool-use)))))
+                    tool-uses))))
 
 (cl-defmethod llm-provider-streaming-media-handler ((_ llm-ollama) msg-receiver _ _)
   (cons 'application/x-ndjson
